/*
 * FCKeditor - The text editor for Internet - http://www.fckeditor.net
 * Copyright (C) 2003-2008 Frederico Caldeira Knabben
 *
 * == BEGIN LICENSE ==
 *
 * Licensed under the terms of any of the following licenses at your
 * choice:
 *
 *  - GNU General Public License Version 2 or later (the "GPL")
 *    http://www.gnu.org/licenses/gpl.html
 *
 *  - GNU Lesser General Public License Version 2.1 or later (the "LGPL")
 *    http://www.gnu.org/licenses/lgpl.html
 *
 *  - Mozilla Public License Version 1.1 or later (the "MPL")
 *    http://www.mozilla.org/MPL/MPL-1.1.html
 *
 * == END LICENSE ==
 *
 * Afrikaans language file.
 */

var FCKLang =
{
// Language direction : "ltr" (left to right) or "rtl" (right to left).
Dir					: "ltr",

ToolbarCollapse		: "Vou Gereedskaps balk toe",
ToolbarExpand		: "Vou Gereedskaps balk oop",

// Toolbar Items and Context Menu
Save				: "Bewaar",
NewPage				: "Nuwe Bladsy",
Preview				: "Voorskou",
Cut					: "Uitsny ",
Copy				: "Kopieer",
Paste				: "Byvoeg",
PasteText			: "Slegs inhoud byvoeg",
PasteWord			: "Van Word af byvoeg",
Print				: "Druk",
SelectAll			: "Selekteer alles",
RemoveFormat		: "Formaat verweider",
InsertLinkLbl		: "Skakel",
InsertLink			: "Skakel byvoeg/verander",
RemoveLink			: "Skakel verweider",
VisitLink			: "Open Link",	//MISSING
Anchor				: "Plekhouer byvoeg/verander",
AnchorDelete		: "Remove Anchor",	//MISSING
InsertImageLbl		: "Beeld",
InsertImage			: "Beeld byvoeg/verander",
InsertFlashLbl		: "Flash",
InsertFlash			: "Flash byvoeg/verander",
InsertTableLbl		: "Tabel",
InsertTable			: "Tabel byvoeg/verander",
InsertLineLbl		: "Lyn",
InsertLine			: "Horisontale lyn byvoeg",
InsertSpecialCharLbl: "Spesiaale karakter",
InsertSpecialChar	: "Spesiaale Karakter byvoeg",
InsertSmileyLbl		: "Smiley",
InsertSmiley		: "Smiley byvoeg",
About				: "Meer oor FCKeditor",
Bold				: "Vet",
Italic				: "Skuins",
Underline			: "Onderstreep",
StrikeThrough		: "Gestreik",
Subscript			: "Subscript",
Superscript			: "Superscript",
LeftJustify			: "Links rig",
CenterJustify		: "Rig Middel",
RightJustify		: "Regs rig",
BlockJustify		: "Blok paradeer",
DecreaseIndent		: "Paradeering verkort",
IncreaseIndent		: "Paradeering verleng",
Blockquote			: "Blockquote",	//MISSING
CreateDiv			: "Create Div Container",	//MISSING
EditDiv				: "Edit Div Container",	//MISSING
DeleteDiv			: "Remove Div Container",	//MISSING
Undo				: "Ont-skep",
Redo				: "Her-skep",
NumberedListLbl		: "Genommerde lys",
NumberedList		: "Genommerde lys byvoeg/verweider",
BulletedListLbl		: "Gepunkte lys",
BulletedList		: "Gepunkte lys byvoeg/verweider",
ShowTableBorders	: "Wys tabel kante",
ShowDetails			: "Wys informasie",
Style				: "Styl",
FontFormat			: "Karakter formaat",
Font				: "Karakters",
FontSize			: "Karakter grote",
TextColor			: "Karakter kleur",
BGColor				: "Agtergrond kleur",
Source				: "Source",
Find				: "Vind",
Replace				: "Vervang",
SpellCheck			: "Spelling nagaan",
UniversalKeyboard	: "Universeele Sleutelbord",
PageBreakLbl		: "Bladsy breek",
PageBreak			: "Bladsy breek byvoeg",

Form			: "Form",
Checkbox		: "HakBox",
RadioButton		: "PuntBox",
TextField		: "Byvoegbare karakter strook",
Textarea		: "Byvoegbare karakter area",
HiddenField		: "Blinde strook",
Button			: "Knop",
SelectionField	: "Opklapbare keuse strook",
ImageButton		: "Beeld knop",

FitWindow		: "Maksimaliseer venster grote",
ShowBlocks		: "Show Blocks",	//MISSING

// Context Menu
EditLink			: "Verander skakel",
CellCM				: "Cell",
RowCM				: "Ry",
ColumnCM			: "Kolom",
InsertRowAfter		: "Insert Row After",	//MISSING
InsertRowBefore		: "Insert Row Before",	//MISSING
DeleteRows			: "Ry verweider",
InsertColumnAfter	: "Insert Column After",	//MISSING
InsertColumnBefore	: "Insert Column Before",	//MISSING
DeleteColumns		: "Kolom verweider",
InsertCellAfter		: "Insert Cell After",	//MISSING
InsertCellBefore	: "Insert Cell Before",	//MISSING
DeleteCells			: "Cell verweider",
MergeCells			: "Cell verenig",
MergeRight			: "Merge Right",	//MISSING
MergeDown			: "Merge Down",	//MISSING
HorizontalSplitCell	: "Split Cell Horizontally",	//MISSING
VerticalSplitCell	: "Split Cell Vertically",	//MISSING
TableDelete			: "Tabel verweider",
CellProperties		: "Cell eienskappe",
TableProperties		: "Tabel eienskappe",
ImageProperties		: "Beeld eienskappe",
FlashProperties		: "Flash eienskappe",

AnchorProp			: "Plekhouer eienskappe",
ButtonProp			: "Knop eienskappe",
CheckboxProp		: "HakBox eienskappe",
HiddenFieldProp		: "Blinde strook eienskappe",
RadioButtonProp		: "PuntBox eienskappe",
ImageButtonProp		: "Beeld knop eienskappe",
TextFieldProp		: "Karakter strook eienskappe",
SelectionFieldProp	: "Opklapbare keuse strook eienskappe",
TextareaProp		: "Karakter area eienskappe",
FormProp			: "Form eienskappe",

FontFormats			: "Normaal;Geformateerd;Adres;Opskrif 1;Opskrif 2;Opskrif 3;Opskrif 4;Opskrif 5;Opskrif 6;Normaal (DIV)",

// Alerts and Messages
ProcessingXHTML		: "XHTML word verarbeit. U geduld asseblief...",
Done				: "Kompleet",
PasteWordConfirm	: "Die informasie wat U probeer byvoeg is warskynlik van Word. Wil U dit reinig voor die byvoeging?",
NotCompatiblePaste	: "Die instruksie is beskikbaar vir Internet Explorer weergawe 5.5 of hor. Wil U dir byvoeg sonder reiniging?",
UnknownToolbarItem	: "Unbekende gereedskaps balk item \"%1\"",
UnknownCommand		: "Unbekende instruksie naam \"%1\"",
NotImplemented		: "Instruksie is nie geimplementeer nie.",
UnknownToolbarSet	: "Gereedskaps balk \"%1\" bestaan nie",
NoActiveX			: "U browser sekuriteit instellings kan die funksies van die editor behinder. U moet die opsie \"Run ActiveX controls and plug-ins\" aktiveer. U ondervinding mag problematies geskiet of sekere funksionaliteit mag verhinder word.",
BrowseServerBlocked : "Die vorraad venster word geblok! Verseker asseblief dat U die \"popup blocker\" instelling verander.",
DialogBlocked		: "Die dialoog venster vir verdere informasie word geblok. De-aktiveer asseblief die \"popup blocker\" instellings wat dit behinder.",
VisitLinkBlocked	: "It was not possible to open a new window. Make sure all popup blockers are disabled.",	//MISSING

// Dialogs
DlgBtnOK			: "OK",
DlgBtnCancel		: "Kanseleer",
DlgBtnClose			: "Sluit",
DlgBtnBrowseServer	: "Server deurblaai",
DlgAdvancedTag		: "Ingewikkeld",
DlgOpOther			: "<Ander>",
DlgInfoTab			: "Info",
DlgAlertUrl			: "Voeg asseblief die URL in",

// General Dialogs Labels
DlgGenNotSet		: "<geen instelling>",
DlgGenId			: "Id",
DlgGenLangDir		: "Taal rigting",
DlgGenLangDirLtr	: "Links na regs (LTR)",
DlgGenLangDirRtl	: "Regs na links (RTL)",
DlgGenLangCode		: "Taal kode",
DlgGenAccessKey		: "Toegang sleutel",
DlgGenName			: "Naam",
DlgGenTabIndex		: "Tab Index",
DlgGenLongDescr		: "Lang beskreiwing URL",
DlgGenClass			: "Skakel Tiepe",
DlgGenTitle			: "Voorbeveelings Titel",
DlgGenContType		: "Voorbeveelings inhoud soort",
DlgGenLinkCharset	: "Geskakelde voorbeeld karakterstel",
DlgGenStyle			: "Styl",

// Image Dialog
DlgImgTitle			: "Beeld eienskappe",
DlgImgInfoTab		: "Beeld informasie",
DlgImgBtnUpload		: "Stuur dit na die Server",
DlgImgURL			: "URL",
DlgImgUpload		: "Uplaai",
DlgImgAlt			: "Alternatiewe beskrywing",
DlgImgWidth			: "Weidte",
DlgImgHeight		: "Hoogde",
DlgImgLockRatio		: "Behou preporsie",
DlgBtnResetSize		: "Herstel groote",
DlgImgBorder		: "Kant",
DlgImgHSpace		: "HSpasie",
DlgImgVSpace		: "VSpasie",
DlgImgAlign			: "Paradeer",
DlgImgAlignLeft		: "Links",
DlgImgAlignAbsBottom: "Abs Onder",
DlgImgAlignAbsMiddle: "Abs Middel",
DlgImgAlignBaseline	: "Baseline",
DlgImgAlignBottom	: "Onder",
DlgImgAlignMiddle	: "Middel",
DlgImgAlignRight	: "Regs",
DlgImgAlignTextTop	: "Text Bo",
DlgImgAlignTop		: "Bo",
DlgImgPreview		: "Voorskou",
DlgImgAlertUrl		: "Voeg asseblief Beeld URL in.",
DlgImgLinkTab		: "Skakel",

// Flash Dialog
DlgFlashTitle		: "Flash eienskappe",
DlgFlashChkPlay		: "Automaties Speel",
DlgFlashChkLoop		: "Herhaling",
DlgFlashChkMenu		: "Laat Flash Menu toe",
DlgFlashScale		: "Scale",
DlgFlashScaleAll	: "Wys alles",
DlgFlashScaleNoBorder	: "Geen kante",
DlgFlashScaleFit	: "Presiese pas",

// Link Dialog
DlgLnkWindowTitle	: "Skakel",
DlgLnkInfoTab		: "Skakel informasie",
DlgLnkTargetTab		: "Mikpunt",

DlgLnkType			: "Skakel soort",
DlgLnkTypeURL		: "URL",
DlgLnkTypeAnchor	: "Skakel na plekhouers in text",
DlgLnkTypeEMail		: "E-Mail",
DlgLnkProto			: "Protokol",
DlgLnkProtoOther	: "<ander>",
DlgLnkURL			: "URL",
DlgLnkAnchorSel		: "Kies 'n plekhouer",
DlgLnkAnchorByName	: "Volgens plekhouer naam",
DlgLnkAnchorById	: "Volgens element Id",
DlgLnkNoAnchors		: "(Geen plekhouers beskikbaar in dokument}",
DlgLnkEMail			: "E-Mail Adres",
DlgLnkEMailSubject	: "Boodskap Opskrif",
DlgLnkEMailBody		: "Boodskap Inhoud",
DlgLnkUpload		: "Oplaai",
DlgLnkBtnUpload		: "Stuur na Server",

DlgLnkTarget		: "Mikpunt",
DlgLnkTargetFrame	: "<raam>",
DlgLnkTargetPopup	: "<popup venster>",
DlgLnkTargetBlank	: "Nuwe Venster (_blank)",
DlgLnkTargetParent	: "Vorige Venster (_parent)",
DlgLnkTargetSelf	: "Selfde Venster (_self)",
DlgLnkTargetTop		: "Boonste Venster (_top)",
DlgLnkTargetFrameName	: "Mikpunt Venster Naam",
DlgLnkPopWinName	: "Popup Venster Naam",
DlgLnkPopWinFeat	: "Popup Venster Geaartheid",
DlgLnkPopResize		: "Verstelbare Groote",
DlgLnkPopLocation	: "Adres Balk",
DlgLnkPopMenu		: "Menu Balk",
DlgLnkPopScroll		: "Gleibalkstuk",
DlgLnkPopStatus		: "Status Balk",
DlgLnkPopToolbar	: "Gereedskap Balk",
DlgLnkPopFullScrn	: "Voll Skerm (IE)",
DlgLnkPopDependent	: "Afhanklik (Netscape)",
DlgLnkPopWidth		: "Weite",
DlgLnkPopHeight		: "Hoogde",
DlgLnkPopLeft		: "Links Posisie",
DlgLnkPopTop		: "Bo Posisie",

DlnLnkMsgNoUrl		: "Voeg asseblief die URL in",
DlnLnkMsgNoEMail	: "Voeg asseblief die e-mail adres in",
DlnLnkMsgNoAnchor	: "Kies asseblief 'n plekhouer",
DlnLnkMsgInvPopName	: "Die popup naam moet begin met alphabetiese karakters sonder spasies.",

// Color Dialog
DlgColorTitle		: "Kies Kleur",
DlgColorBtnClear	: "Maak skoon",
DlgColorHighlight	: "Highlight",
DlgColorSelected	: "Geselekteer",

// Smiley Dialog
DlgSmileyTitle		: "Voeg Smiley by",

// Special Character Dialog
DlgSpecialCharTitle	: "Kies spesiale karakter",

// Table Dialog
DlgTableTitle		: "Tabel eienskappe",
DlgTableRows		: "Reie",
DlgTableColumns		: "Kolome",
DlgTableBorder		: "Kant groote",
DlgTableAlign		: "Parideering",
DlgTableAlignNotSet	: "<geen instelling>",
DlgTableAlignLeft	: "Links",
DlgTableAlignCenter	: "Middel",
DlgTableAlignRight	: "Regs",
DlgTableWidth		: "Weite",
DlgTableWidthPx		: "pixels",
DlgTableWidthPc		: "percent",
DlgTableHeight		: "Hoogde",
DlgTableCellSpace	: "Cell spasieering",
DlgTableCellPad		: "Cell buffer",
DlgTableCaption		: "Beskreiwing",
DlgTableSummary		: "Opsomming",

// Table Cell Dialog
DlgCellTitle		: "Cell eienskappe",
DlgCellWidth		: "Weite",
DlgCellWidthPx		: "pixels",
DlgCellWidthPc		: "percent",
DlgCellHeight		: "Hoogde",
DlgCellWordWrap		: "Woord Wrap",
DlgCellWordWrapNotSet	: "<geen instelling>",
DlgCellWordWrapYes	: "Ja",
DlgCellWordWrapNo	: "Nee",
DlgCellHorAlign		: "Horisontale rigting",
DlgCellHorAlignNotSet	: "<geen instelling>",
DlgCellHorAlignLeft	: "Links",
DlgCellHorAlignCenter	: "Middel",
DlgCellHorAlignRight: "Regs",
DlgCellVerAlign		: "Vertikale rigting",
DlgCellVerAlignNotSet	: "<geen instelling>",
DlgCellVerAlignTop	: "Bo",
DlgCellVerAlignMiddle	: "Middel",
DlgCellVerAlignBottom	: "Onder",
DlgCellVerAlignBaseline	: "Baseline",
DlgCellRowSpan		: "Rei strekking",
DlgCellCollSpan		: "Kolom strekking",
DlgCellBackColor	: "Agtergrond Kleur",
DlgCellBorderColor	: "Kant Kleur",
DlgCellBtnSelect	: "Keuse...",

// Find and Replace Dialog
DlgFindAndReplaceTitle	: "Find and Replace",	//MISSING

// Find Dialog
DlgFindTitle		: "Vind",
DlgFindFindBtn		: "Vind",
DlgFindNotFoundMsg	: "Die gespesifiseerde karakters word nie gevind nie.",

// Replace Dialog
DlgReplaceTitle			: "Vervang",
DlgReplaceFindLbl		: "Soek wat:",
DlgReplaceReplaceLbl	: "Vervang met:",
DlgReplaceCaseChk		: "Vergelyk karakter skryfweise",
DlgReplaceReplaceBtn	: "Vervang",
DlgReplaceReplAllBtn	: "Vervang alles",
DlgReplaceWordChk		: "Vergelyk komplete woord",

// Paste Operations / Dialog
PasteErrorCut	: "U browser se sekuriteit instelling behinder die uitsny aksie. Gebruik asseblief die sleutel kombenasie(Ctrl+X).",
PasteErrorCopy	: "U browser se sekuriteit instelling behinder die kopieerings aksie. Gebruik asseblief die sleutel kombenasie(Ctrl+C).",

PasteAsText		: "Voeg slegs karakters by",
PasteFromWord	: "Byvoeging uit Word",

DlgPasteMsg2	: "Voeg asseblief die inhoud in die gegewe box by met sleutel kombenasie(<STRONG>Ctrl+V</STRONG>) en druk <STRONG>OK</STRONG>.",
DlgPasteSec		: "Because of your browser security settings, the editor is not able to access your clipboard data directly. You are required to paste it again in this window.",	//MISSING
DlgPasteIgnoreFont		: "Ignoreer karakter soort defenisies",
DlgPasteRemoveStyles	: "Verweider Styl defenisies",

// Color Picker
ColorAutomatic	: "Automaties",
ColorMoreColors	: "Meer Kleure...",

// Document Properties
DocProps		: "Dokument Eienskappe",

// Anchor Dialog
DlgAnchorTitle		: "Plekhouer Eienskappe",
DlgAnchorName		: "Plekhouer Naam",
DlgAnchorErrorName	: "Voltooi die plekhouer naam asseblief",

// Speller Pages Dialog
DlgSpellNotInDic		: "Nie in woordeboek nie",
DlgSpellChangeTo		: "Verander na",
DlgSpellBtnIgnore		: "Ignoreer",
DlgSpellBtnIgnoreAll	: "Ignoreer na-volgende",
DlgSpellBtnReplace		: "Vervang",
DlgSpellBtnReplaceAll	: "vervang na-volgende",
DlgSpellBtnUndo			: "Ont-skep",
DlgSpellNoSuggestions	: "- Geen voorstel -",
DlgSpellProgress		: "Spelling word beproef...",
DlgSpellNoMispell		: "Spellproef kompleet: Geen foute",
DlgSpellNoChanges		: "Spellproef kompleet: Geen woord veranderings",
DlgSpellOneChange		: "Spellproef kompleet: Een woord verander",
DlgSpellManyChanges		: "Spellproef kompleet: %1 woorde verander",

IeSpellDownload			: "Geen Spellproefer geinstaleer nie. Wil U dit aflaai?",

// Button Dialog
DlgButtonText		: "Karakters (Waarde)",
DlgButtonType		: "Soort",
DlgButtonTypeBtn	: "Knop",
DlgButtonTypeSbm	: "Indien",
DlgButtonTypeRst	: "Reset",

// Checkbox and Radio Button Dialogs
DlgCheckboxName		: "Naam",
DlgCheckboxValue	: "Waarde",
DlgCheckboxSelected	: "Uitgekies",

// Form Dialog
DlgFormName		: "Naam",
DlgFormAction	: "Aksie",
DlgFormMethod	: "Metode",

// Select Field Dialog
DlgSelectName		: "Naam",
DlgSelectValue		: "Waarde",
DlgSelectSize		: "Grote",
DlgSelectLines		: "lyne",
DlgSelectChkMulti	: "Laat meerere keuses toe",
DlgSelectOpAvail	: "Beskikbare Opsies",
DlgSelectOpText		: "Karakters",
DlgSelectOpValue	: "Waarde",
DlgSelectBtnAdd		: "Byvoeg",
DlgSelectBtnModify	: "Verander",
DlgSelectBtnUp		: "Op",
DlgSelectBtnDown	: "Af",
DlgSelectBtnSetValue : "Stel as uitgekiesde waarde",
DlgSelectBtnDelete	: "Verweider",

// Textarea Dialog
DlgTextareaName	: "Naam",
DlgTextareaCols	: "Kolom",
DlgTextareaRows	: "Reie",

// Text Field Dialog
DlgTextName			: "Naam",
DlgTextValue		: "Waarde",
DlgTextCharWidth	: "Karakter weite",
DlgTextMaxChars		: "Maximale karakters",
DlgTextType			: "Soort",
DlgTextTypeText		: "Karakters",
DlgTextTypePass		: "Wagwoord",

// Hidden Field Dialog
DlgHiddenName	: "Naam",
DlgHiddenValue	: "Waarde",

// Bulleted List Dialog
BulletedListProp	: "Gepunkte lys eienskappe",
NumberedListProp	: "Genommerde lys eienskappe",
DlgLstStart			: "Begin",
DlgLstType			: "Soort",
DlgLstTypeCircle	: "Sirkel",
DlgLstTypeDisc		: "Skyf",
DlgLstTypeSquare	: "Vierkant",
DlgLstTypeNumbers	: "Nommer (1, 2, 3)",
DlgLstTypeLCase		: "Klein Letters (a, b, c)",
DlgLstTypeUCase		: "Hoof Letters (A, B, C)",
DlgLstTypeSRoman	: "Klein Romeinse nommers (i, ii, iii)",
DlgLstTypeLRoman	: "Groot Romeinse nommers (I, II, III)",

// Document Properties Dialog
DlgDocGeneralTab	: "Algemeen",
DlgDocBackTab		: "Agtergrond",
DlgDocColorsTab		: "Kleure en Rante",
DlgDocMetaTab		: "Meta Data",

DlgDocPageTitle		: "Bladsy Opskrif",
DlgDocLangDir		: "Taal rigting",
DlgDocLangDirLTR	: "Link na Regs (LTR)",
DlgDocLangDirRTL	: "Regs na Links (RTL)",
DlgDocLangCode		: "Taal Kode",
DlgDocCharSet		: "Karakterstel Kodeering",
DlgDocCharSetCE		: "Sentraal Europa",
DlgDocCharSetCT		: "Chinees Traditioneel (Big5)",
DlgDocCharSetCR		: "Cyrillic",
DlgDocCharSetGR		: "Grieks",
DlgDocCharSetJP		: "Japanees",
DlgDocCharSetKR		: "Koreans",
DlgDocCharSetTR		: "Turks",
DlgDocCharSetUN		: "Unicode (UTF-8)",
DlgDocCharSetWE		: "Western European",
DlgDocCharSetOther	: "Ander Karakterstel Kodeering",

DlgDocDocType		: "Dokument Opskrif Soort",
DlgDocDocTypeOther	: "Ander Dokument Opskrif Soort",
DlgDocIncXHTML		: "Voeg XHTML verklaring by",
DlgDocBgColor		: "Agtergrond kleur",
DlgDocBgImage		: "Agtergrond Beeld URL",
DlgDocBgNoScroll	: "Vasgeklemde Agtergrond",
DlgDocCText			: "Karakters",
DlgDocCLink			: "Skakel",
DlgDocCVisited		: "Besoekte Skakel",
DlgDocCActive		: "Aktiewe Skakel",
DlgDocMargins		: "Bladsy Rante",
DlgDocMaTop			: "Bo",
DlgDocMaLeft		: "Links",
DlgDocMaRight		: "Regs",
DlgDocMaBottom		: "Onder",
DlgDocMeIndex		: "Dokument Index Sleutelwoorde(comma verdeelt)",
DlgDocMeDescr		: "Dokument Beskrywing",
DlgDocMeAuthor		: "Skrywer",
DlgDocMeCopy		: "Kopiereg",
DlgDocPreview		: "Voorskou",

// Templates Dialog
Templates			: "Templates",
DlgTemplatesTitle	: "Inhoud Templates",
DlgTemplatesSelMsg	: "Kies die template om te gebruik in die editor<br>(Inhoud word vervang!):",
DlgTemplatesLoading	: "Templates word gelaai. U geduld asseblief...",
DlgTemplatesNoTpl	: "(Geen templates gedefinieerd)",
DlgTemplatesReplace	: "Vervang bestaande inhoud",

// About Dialog
DlgAboutAboutTab	: "Meer oor",
DlgAboutBrowserInfoTab	: "Blaai Informasie deur",
DlgAboutLicenseTab	: "Lesensie",
DlgAboutVersion		: "weergawe",
DlgAboutInfo		: "Vir meer informasie gaan na ",

// Div Dialog
DlgDivGeneralTab	: "General",	//MISSING
DlgDivAdvancedTab	: "Advanced",	//MISSING
DlgDivStyle		: "Style",	//MISSING
DlgDivInlineStyle	: "Inline Style"	//MISSING
};
